utils

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoadObjectFromFile added in v0.2.0

func LoadObjectFromFile(file string) (*unstructured.Unstructured, error)

LoadObjectFromFile loads an object from "objects" directory with given file name

func ToConcrete added in v0.2.0

func ToConcrete[T client.Object](obj *unstructured.Unstructured, concrete T) error

ToConcrete converts an unstructured object to a concrete object

Types

type ClusterCollector added in v0.2.0

type ClusterCollector struct {
	// contains filtered or unexported fields
}

ClusterCollector collects resources from the cluster and stores them in artifacts directory.

func NewClusterCollector added in v0.2.0

func NewClusterCollector(
	client client.Client, clientset *kubernetes.Clientset, artifactsDirectory string,
) *ClusterCollector

func (*ClusterCollector) Run added in v0.2.0

func (c *ClusterCollector) Run(ctx context.Context) error

Jump to